@@ -1,3 +1,6 @@
+import random
+import string
+
 def number_to_abbrevation(num):
     label = ['', 'K', 'M', 'B', 'T']
     i = 0
@@ -13,4 +16,8 @@ def size_to_abbrevation(num):
     while num > 1024:
         num /= 1024
         i += 1
-    return f'{num:.1f} {label[i]}'
\ No newline at end of file
+    return f'{num:.1f} {label[i]}'
+
+
+def get_random_string(length):
+    return ''.join(random.choice(string.ascii_uppercase) for i in range(length))
\ No newline at end of file
